<?php
/**
 * Classe que implementa o desenho de grficos para a biblioteca pChart
 */
final class TPChartDesigner extends TChartDesigner
{
    /**
     * Desenha um grfico de linhas
     * @param $title ttulo do graico
     * @param $data matriz contendo as sries de dados
     * @param $xlabels vetor contendo os rtulos do eixo X
     * @param $ylabel  rtulo do eixo Y
     * @param $width largura do grfico
     * @param $height altura do grfico
     * @param $outputPath caminho de sada do grfico
     */
    public function drawLineChart($title, $data, $xlabels, $ylabel, $width, $height, $outputPath)
    {
        // cria o modelo de dados
        $modelo = new pData;
        
        foreach ($data as $legend => $serie)
        {
            $newdata = array();
            foreach ($serie as $value)
            {
                $newdata[$legend][] = $value == NULL ? VOID : $value;
            }
            
            $modelo->addPoints($newdata[$legend], $legend);
        }
        
        $modelo->setAxisName(0, $ylabel); 
        $modelo->addPoints($xlabels, "Labels");
        $modelo->setAbscissa("Labels"); 
        
        // cria o objeto que ir conter a imagem do grfico
        $imagem = new pImage($width, $height, $modelo); 
        
        // adiciona uma borda na forma de um retngulo dentro da imagem
        $imagem->drawRectangle(0, 0, $width-1, $height-1, array("R"=>0,"G"=>0,"B"=>0)); 
          
        // escreve um ttulo dentro do grfico
        $imagem->setFontProperties(array("FontName"=>"app/lib/pchart/fonts/Forgotte.ttf","FontSize"=>11)); 
        $imagem->drawText(60, 35, $title, array("FontSize"=>20,"Align"=>TEXT_ALIGN_BOTTOMLEFT)); 
        
        // define a fonte dos dados do grfico 
        $imagem->setFontProperties(array("FontName"=>"app/lib/pchart/fonts/pf_arma_five.ttf","FontSize"=>6)); 
        
        // define a rea do grfico
        $imagem->setGraphArea(60, 40, $width-50, $height-30);
        
        // define a escala do grfico
        $scaleSettings = array("XMargin"=>10,"YMargin"=>10,"CycleBackground"=>TRUE,
                               "GridR"=>200,"GridG"=>200,"GridB"=>200);
        $imagem->drawScale($scaleSettings); 
        
        // liga a suavizao de linhas
        $imagem->Antialias = TRUE; 
        
        // desenha o grfico de linhas
        $imagem->drawLineChart(array('DisplayValues'=>TRUE)); 
        
        // desenha a legenda do grfico 
        $imagem->drawLegend(60, $height-13, array("Style"=>LEGEND_NOBORDER,"Mode"=>LEGEND_HORIZONTAL)); 
        
        // grava o grfico em um arquivo
        $imagem->render($outputPath); 
    }
    
    /**
     * Desenha um grfico de barras
     * @param $title ttulo do graico
     * @param $data matriz contendo as sries de dados
     * @param $xlabels vetor contendo os rtulos do eixo X
     * @param $ylabel  rtulo do eixo Y
     * @param $width largura do grfico
     * @param $height altura do grfico
     * @param $outputPath caminho de sada do grfico
     */
    public function drawBarChart($title,  $data, $xlabels, $ylabel, $width, $height, $outputPath)
    {
        // cria o modelo de dados
        $modelo = new pData;
           
        foreach ($data as $legend => $serie)
        {
            $newdata = array();
            foreach ($serie as $value)
            {
                $newdata[$legend][] = $value == NULL ? VOID : $value;
            }
            
            $modelo->addPoints($newdata[$legend], $legend);
        }
        
        $modelo->setAxisName(0, $ylabel);
        $modelo->addPoints($xlabels, "Labels");
        $modelo->setAbscissa("Labels");
        
        // cria o objeto que ir conter a imagem do grfico
        $imagem = new pImage($width, $height, $modelo); 
        
        // desliga a suavizao de linhas
        $imagem->Antialias = FALSE; 
        
        // adiciona uma borda na forma de um retngulo dentro da imagem 
        $imagem->drawRectangle(0,0, $width-1, $height-1, array("R"=>0,"G"=>0,"B"=>0)); 
        
        // escreve um ttulo dentro do grfico
        $imagem->setFontProperties(array("FontName"=>"app/lib/pchart/fonts/Forgotte.ttf","FontSize"=>11)); 
        $imagem->drawText(60,35, $title,array("FontSize"=>20,"Align"=>TEXT_ALIGN_BOTTOMLEFT));
        
        // define a fonte dos dados do grfico
        $imagem->setFontProperties(array("FontName"=>"app/lib/pchart/fonts/pf_arma_five.ttf","FontSize"=>6));
        
        // define a rea do grfico 
        $imagem->setGraphArea(60, 40, $width-50, $height-30); 
        
        // define a escala do grfico
        $scaleSettings = array("GridR"=>200,"GridG"=>200,"GridB"=>200,"CycleBackground"=>TRUE); 
        $imagem->drawScale($scaleSettings); 
        
        // desenha a legenda do grfico
        $imagem->drawLegend(60,$height-13,array("Style"=>LEGEND_NOBORDER,"Mode"=>LEGEND_HORIZONTAL)); 
        
        // cria uma sombra nas barras do grfico  
        $imagem->setShadow(TRUE,array("X"=>1,"Y"=>1,"R"=>0,"G"=>0,"B"=>0,"Alpha"=>10)); 
        
        // desenha o grfico de barras
        $imagem->drawBarChart(array("DisplayPos"=>LABEL_POS_INSIDE, // valores dentro das barras
                                    "DisplayValues"=>TRUE,"Surrounding"=>200)); 
        
        // grava o grfico em um arquivo
        $imagem->render($outputPath);
    }
    
    /**
     * Desenha um grfico de torta
     * @param $title ttulo do graico
     * @param $data vetor contendo os dados do grfico
     * @param $width largura do grfico
     * @param $height altura do grfico
     * @param $outputPath caminho de sada do grfico
     */
    public function drawPieChart($title, $data, $width, $height, $outputPath)
    {
        // cria o modelo de dados
        $modelo = new pData;
        
        $newdata = array();
        foreach ($data as $legend => $value)
        {
            $newdata[] = $value === NULL ? VOID : ($value === 0 ? 0.0001 : $value);
            $labels[]  = $legend;
        }
        
        $modelo->addPoints($newdata, "ScoreA");
        
        /* Define the absissa serie */
        $modelo->addPoints($labels,"Labels");
        $modelo->setAbscissa("Labels");
        
        // cria o objeto que ir conter a imagem do grfico
        $imagem = new pImage($width, $height, $modelo);
        
        // adiciona uma borda na forma de um retngulo dentro da imagem
        $imagem->drawRectangle(0, 0, $width-1, $height-1, array("R"=>0,"G"=>0,"B"=>0));
        
        // escreve um ttulo dentro do grfico
        $imagem->setFontProperties(array("FontName"=>"app/lib/pchart/fonts/Forgotte.ttf","FontSize"=>11));
        $imagem->drawText(60,35, $title, array("FontSize"=>20,"Align"=>TEXT_ALIGN_BOTTOMLEFT));
        
        // define a fonte dos dados do grfico
        $imagem->setFontProperties(array("FontName"=>"app/lib/pchart/fonts/Forgotte.ttf","FontSize"=>10,"R"=>80,"G"=>80,"B"=>80)); 
        
        // cria o grfico de torta 
        $pie = new pPie($imagem, $modelo); 
        
        // desenha o grfico de torta
        $pie->draw3DPie($width/2, $height/2,
                             array('WriteValues'=>TRUE, // escreve valores
                                   'DrawLabels'=>TRUE,  // escreve labels
                                   "Radius" => $width /4, // radio
                                   'ValueR'=>0, 'ValueG'=>0, 'ValueB'=>0, 'ValueAlpha' => 80));
         
        // desenha a legenda do grfico
        $imagem->setShadow(FALSE); 
        $pie->drawPieLegend(15, 40, array("Alpha"=>20));
        
        // grava o grfico em um arquivo
        $imagem->render($outputPath);
    }
}
?>
